@@ -1,6 +1,6 @@
 package PDL::DSP::Windows;
 
-our $VERSION = '0.008003'; # TRIAL
+our $VERSION = '0.008004'; # TRIAL
 
 use strict;
 use warnings;
@@ -191,14 +191,19 @@ PDL::DSP::Windows - Window functions for signal processing
 =head1 SYNOPSIS
 
     use PDL;
-    use PDL::DSP::Windows('window');
-    my $samples = window( 10, 'tukey', { params => .5 });
+    use PDL::DSP::Windows 'window';
 
-    use PDL;
-    use PDL::DSP::Windows;
-    my $win = PDL::DSP::Windows->new( 10, 'tukey', { params => .5 });
-    print $win->coherent_gain, "\n";
-    $win->plot;
+    my $window;
+
+    # Create a window with the helper
+    $window = window( 10, 'tukey', { params => .5 });
+
+    # Or with the OO constructor, which is the same
+    $window = PDL::DSP::Windows->new( 10, 'tukey', { params => .5 });
+
+    print $window->coherent_gain, "\n";
+
+    $window->plot; # Requires PDL::Graphics::Gnuplot
 
 =head1 DESCRIPTION
 
@@ -877,15 +882,17 @@ sub process_gain { 1 / shift->enbw }
 
 =for ref
 
-**BROKEN**.
 Compute and return the scalloping loss of the window.
 
 =cut
 
 sub scallop_loss {
-    my ($w) = @_;
-    my $x = PDL::Basic::sequence($w) * ( PI / $w->nelem );
-    sqrt( ( $w * cos($x) )->sum ** 2 + ( $w * sin($x) )->sum ** 2 ) / $w->sum;
+    my $w = shift->samples;
+
+    # Adapted from https://stackoverflow.com/a/40912607
+    my $num = abs( ( $w * exp( -( ( PDL::Core::pdl("1i") * PDL::sequence($w) * PI ) / $w->nelem ) ) )->sum );
+
+    20 * PDL::Ops::log10( $num / abs($w)->sum );
 }
 
 =head1 WINDOW FUNCTIONS
